@@ -47,13 +47,10 @@
 #include <k3socketbase.h>
 #include <KPasswordDialog>
 #include <KInputDialog>
-#include <KIcon>
 #include <KActionMenu>
 #include <KComponentData>
 
 #include "jabberconnector.h"
-#include "jabberclient.h"
-#include "jabberprotocol.h"
 #include "jabberresourcepool.h"
 #include "jabbercontactpool.h"
 // #include "jabberfiletransfer.h"
