@@ -38,22 +38,20 @@ This is the standard main function of a KDE application
 #include <QCommandLineParser>
 #include <QCommandLineOption>
 
-static const char *description =
-    I18N_NOOP("KsirK Skin Editor");
-// INSERT A DESCRIPTION FOR YOUR APPLICATION HERE
-
 int main(int argc, char *argv[])
 {
   qCDebug(KSIRKSKINEDITOR_LOG) << "Hello World!";
   // Fixes blurry icons with fractional scaling
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
   QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
+#endif
   QApplication app(argc, argv);
   KLocalizedString::setApplicationDomain("ksirkskineditor");
   KAboutData aboutData(
     QStringLiteral("ksirkskineditor"),
     i18n("KsirK Skin Editor"),
     QStringLiteral(KSIRK_VERSION_STRING),
-    i18n(description),
+    i18n("KsirK Skin Editor"),
     KAboutLicense::GPL,
     i18n("(c) 2008, Gaël de Chalendar\n"),
     i18n("For help and user manual, please see\nThe KsirK Web site"),
