@@ -28,7 +28,6 @@
 #include <QFile>
 // #include <QDom>
 #include <QPainter>
-#include <QPixmap>
 #include <QGraphicsItem>
 #include <QGraphicsScene>
 #include <QXmlStreamReader>
@@ -38,6 +37,7 @@
 #include <KMessageBox>
 #include <KConfig>
 #include <KConfigGroup>
+#include <QRegExp>
 
 namespace KsirkSkinEditor
 {
@@ -1000,7 +1000,8 @@ void ONU::loadPoolIds(const QString& fileName)
     {
       qCDebug(KSIRKSKINEDITOR_LOG) << xml.text().toString();
       QXmlStreamAttributes attributes = xml.attributes ();
-      QStringRef id = attributes.value(QLatin1String(""), QStringLiteral("id") );
+      auto id = attributes.value(QLatin1String(""), QStringLiteral("id") );
+
       if (!id.isEmpty() && !reg.exactMatch(id.toString()))
       {
         m_poolIds.push_back(id.toString());
